@@ -213,6 +213,9 @@ class QueryModel(Query):
     # __advanced_search__.
     __simple_search__ = []
 
+    # Default order by to use.
+    __order_by__ = None
+
     @property
     def Model(self):
         """Return primary entity model class."""
@@ -256,11 +259,14 @@ class QueryModel(Query):
         # have at least simple filter match.
         return and_(*[or_(*filters) for filters in term_filters])
 
-    def search(self, search_string=None, search_dict=None,
-               limit=None, offset=None, order_by=None):
+    def search(self, search_string=None, search_dict=None, **search_options):
         """Perform combination of simple/advanced searching with optional
         limit/offset support.
         """
+        search_options.setdefault('limit', None)
+        search_options.setdefault('offset', None)
+        search_options.setdefault('order_by', self.__order_by__)
+
         query = self
         model_primary_keys = self.Model.primary_keys
 
@@ -272,14 +278,21 @@ class QueryModel(Query):
         # user keywords (one-to-many), then for something like the first 25
         # users, we may actually have more than that many records since we're
         # joining on many records from the user keywords table.
-        model_query = original = self.session.query(
-            *model_primary_keys).distinct()
+        original = (self.lazyload('*')
+                    .load_only(*[pkey.key
+                                 for pkey in model_primary_keys])
+                    .distinct())
+
+        # Use the original query so that we preserve joins and where
+        # statements.
+        model_query = original
 
         if self.whereclause is not None:
-            # Transfer the whereclause of the originating query to the new
-            # search query. This is done so the the originating query can set
-            # "global" filters for search which will be included in pagination.
-            model_query = model_query.filter(self.whereclause)
+            # If our base query contains a whereclause, then we need to
+            # compelete the "transfer" of the base query's where statements to
+            # model_query by wiping out the base query's criterion. i.e. We
+            # only want to maintain selects and froms in the base query and
+            # keep wheres in the model_query.
 
             # Call a generative query method that won't modify its state. This
             # is basically a no-op used to copy the query object and modify it
@@ -299,22 +312,23 @@ class QueryModel(Query):
             model_query = model_query.filter(
                 self.advanced_filter(search_dict))
 
-        if order_by is not None:
-            if not isinstance(order_by, (list, tuple)):
-                order_by = [order_by]
-            model_query = model_query.order_by(*order_by)
+        if search_options['order_by'] is not None:
+            if not isinstance(search_options['order_by'], (list, tuple)):
+                search_options['order_by'] = [search_options['order_by']]
+            model_query = model_query.order_by(*search_options['order_by'])
 
-        if limit is not None:
-            model_query = model_query.limit(limit)
+        if search_options['limit'] is not None:
+            model_query = model_query.limit(search_options['limit'])
 
-        if offset is not None:
-            model_query = model_query.offset(offset)
+        if search_options['offset'] is not None:
+            model_query = model_query.offset(search_options['offset'])
 
         if model_query != original:
             subquery = model_query.subquery()
 
-            query = query.join(subquery, join_subquery_on_columns(
-                subquery, model_primary_keys))
+            query = query.join(subquery,
+                               join_subquery_on_columns(subquery,
+                                                        model_primary_keys))
 
         return query
 
